==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/databox/kotlin/inputs/FilterFileDetailsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.databox.kotlin.inputs

import com.pulumi.azurenative.databox.inputs.FilterFileDetailsArgs.builder
import com.pulumi.azurenative.databox.kotlin.enums.FilterFileType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Details of the filter files to be used for data transfer.
 * @property filterFilePath Path of the file that contains the details of all items to transfer.
 * @property filterFileType Type of the filter file.
 */
public data class FilterFileDetailsArgs(
    public val filterFilePath: Output<String>,
    public val filterFileType: Output<Either<String, FilterFileType>>,
) : ConvertibleToJava<com.pulumi.azurenative.databox.inputs.FilterFileDetailsArgs> {
    override fun toJava(): com.pulumi.azurenative.databox.inputs.FilterFileDetailsArgs =
        com.pulumi.azurenative.databox.inputs.FilterFileDetailsArgs.builder()
            .filterFilePath(filterFilePath.applyValue({ args0 -> args0 }))
            .filterFileType(
                filterFileType.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [FilterFileDetailsArgs].
 */
@PulumiTagMarker
public class FilterFileDetailsArgsBuilder internal constructor() {
    private var filterFilePath: Output<String>? = null

    private var filterFileType: Output<Either<String, FilterFileType>>? = null

    /**
     * @param value Path of the file that contains the details of all items to transfer.
     */
    @JvmName("jxbpfywlmdinatpw")
    public suspend fun filterFilePath(`value`: Output<String>) {
        this.filterFilePath = value
    }

    /**
     * @param value Type of the filter file.
     */
    @JvmName("wtqooyyyllyrlrri")
    public suspend fun filterFileType(`value`: Output<Either<String, FilterFileType>>) {
        this.filterFileType = value
    }

    /**
     * @param value Path of the file that contains the details of all items to transfer.
     */
    @JvmName("xjbjagooynrsycgc")
    public suspend fun filterFilePath(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.filterFilePath = mapped
    }

    /**
     * @param value Type of the filter file.
     */
    @JvmName("twtrkkyatyivbtcc")
    public suspend fun filterFileType(`value`: Either<String, FilterFileType>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.filterFileType = mapped
    }

    /**
     * @param value Type of the filter file.
     */
    @JvmName("wfgwwfmkfpvrsyou")
    public fun filterFileType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, FilterFileType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.filterFileType = mapped
    }

    /**
     * @param value Type of the filter file.
     */
    @JvmName("aqfgskrqcfaqmfwu")
    public fun filterFileType(`value`: FilterFileType) {
        val toBeMapped = Either.ofRight<String, FilterFileType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.filterFileType = mapped
    }

    internal fun build(): FilterFileDetailsArgs = FilterFileDetailsArgs(
        filterFilePath = filterFilePath ?: throw PulumiNullFieldException("filterFilePath"),
        filterFileType = filterFileType ?: throw PulumiNullFieldException("filterFileType"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/databox/kotlin/inputs/FilterFileDetailsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.databox.kotlin.inputs

import com.pulumi.azurenative.databox.inputs.FilterFileDetailsArgs.builder
import com.pulumi.azurenative.databox.kotlin.enums.FilterFileType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Details of the filter files to be used for data transfer.
 * @property filterFilePath Path of the file that contains the details of all items to transfer.
 * @property filterFileType Type of the filter file.
 */
public data class FilterFileDetailsArgs(
    public val filterFilePath: Output<String>,
    public val filterFileType: Output<Either<String, FilterFileType>>,
) : ConvertibleToJava<com.pulumi.azurenative.databox.inputs.FilterFileDetailsArgs> {
    override fun toJava(): com.pulumi.azurenative.databox.inputs.FilterFileDetailsArgs =
        com.pulumi.azurenative.databox.inputs.FilterFileDetailsArgs.builder()
            .filterFilePath(filterFilePath.applyValue({ args0 -> args0 }))
            .filterFileType(
                filterFileType.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [FilterFileDetailsArgs].
 */
@PulumiTagMarker
public class FilterFileDetailsArgsBuilder internal constructor() {
    private var filterFilePath: Output<String>? = null

    private var filterFileType: Output<Either<String, FilterFileType>>? = null

    /**
     * @param value Path of the file that contains the details of all items to transfer.
     */
    @JvmName("yysqhwwqmoivcgsi")
    public suspend fun filterFilePath(`value`: Output<String>) {
        this.filterFilePath = value
    }

    /**
     * @param value Type of the filter file.
     */
    @JvmName("pltrtcgfceiovvcv")
    public suspend fun filterFileType(`value`: Output<Either<String, FilterFileType>>) {
        this.filterFileType = value
    }

    /**
     * @param value Path of the file that contains the details of all items to transfer.
     */
    @JvmName("mbujgnhnlmusqeeb")
    public suspend fun filterFilePath(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.filterFilePath = mapped
    }

    /**
     * @param value Type of the filter file.
     */
    @JvmName("rwqlieojdcqvubti")
    public suspend fun filterFileType(`value`: Either<String, FilterFileType>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.filterFileType = mapped
    }

    /**
     * @param value Type of the filter file.
     */
    @JvmName("ibpttowhumdcanth")
    public fun filterFileType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, FilterFileType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.filterFileType = mapped
    }

    /**
     * @param value Type of the filter file.
     */
    @JvmName("fdcirpatwisnvxlf")
    public fun filterFileType(`value`: FilterFileType) {
        val toBeMapped = Either.ofRight<String, FilterFileType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.filterFileType = mapped
    }

    internal fun build(): FilterFileDetailsArgs = FilterFileDetailsArgs(
        filterFilePath = filterFilePath ?: throw PulumiNullFieldException("filterFilePath"),
        filterFileType = filterFileType ?: throw PulumiNullFieldException("filterFileType"),
    )
}
